==> openGion_dev_5.1.9.0.zip: opengion/uap/webapps/gf/db/mysql/sql/01_TABLE/GF95S.sql <==
/**************************************************************************/
/* GF95 ( DBセット基準書 )                                                */
/*                                                                        */
/* Created : 2010/08/02 13:06:12                                          */
/**************************************************************************/
CREATE TABLE GF95 (
   SYSTEM_ID  VARCHAR(10)                                                          /* 10  システムID     */
 , PGID       VARCHAR(30)                 NOT NULL                                 /* 20  PG-ID          */
 , NMSYORI    VARCHAR(100)                                                         /* 30  処理グループ名 */
 , SEQ        INTEGER         DEFAULT 0   NOT NULL                                 /* 40  順             */
 , TABLE_NAME VARCHAR(50)                 NOT NULL                                 /* 50  テーブル名     */
 , CLM        VARCHAR(30)                                                          /* 60  項目           */
 , MOTO       VARCHAR(30)                                                          /* 70  入力元         */
 , ADDACT     TEXT                                                                 /* 80  追加時         */
 , MODIACT    TEXT                                                                 /* 90  更新時         */
 , DELACT     TEXT                                                                 /* 100 削除時         */
 , UNIQ       BIGINT                      NOT NULL PRIMARY KEY AUTO_INCREMENT      /* 110 ユニークキー   */
 , FGJ        VARCHAR(1)      DEFAULT '1' NOT NULL                                 /* 120 状態フラグ     */
 , DYSET      VARCHAR(14)                                                          /* 130 登録日時       */
 , USRSET     VARCHAR(10)                                                          /* 140 作成社員       */
 , DYUPD      VARCHAR(14)                                                          /* 150 更新日時       */
 , PGUPD      VARCHAR(10)                                                          /* 160 更新PG         */
 , USRUPD     VARCHAR(10)                                                          /* 170 更新者         */
);

==> openGion_dev_5.2.0.0.zip: opengion/uap/webapps/gf/db/mysql/sql/01_TABLE/GF95S.sql <==
/**************************************************************************/
/* GF95 ( DBセット基準書 )                                                */
/*                                                                        */
/* Created : 2010/08/05 08:49:46                                          */
/**************************************************************************/
CREATE TABLE GF95 (
   SYSTEM_ID  VARCHAR(10)                                                          /* 10  システムID     */
 , PGID       VARCHAR(30)                 NOT NULL                                 /* 20  PG-ID          */
 , NMSYORI    VARCHAR(100)                                                         /* 30  処理グループ名 */
 , SEQ        INTEGER         DEFAULT 0   NOT NULL                                 /* 40  順             */
 , TABLE_NAME VARCHAR(50)                 NOT NULL                                 /* 50  テーブル名     */
 , CLM        VARCHAR(30)                                                          /* 60  項目           */
 , MOTO       VARCHAR(30)                                                          /* 70  入力元         */
 , ADDACT     TEXT                                                                 /* 80  追加時         */
 , MODIACT    TEXT                                                                 /* 90  更新時         */
 , DELACT     TEXT                                                                 /* 100 削除時         */
 , UNIQ       BIGINT                      NOT NULL PRIMARY KEY AUTO_INCREMENT      /* 110 ユニークキー   */
 , FGJ        VARCHAR(1)      DEFAULT '1' NOT NULL                                 /* 120 状態フラグ     */
 , DYSET      VARCHAR(14)                                                          /* 130 登録日時       */
 , PGSET      VARCHAR(10)                                                          /* 140 作成PG         */
 , PGPSET     VARCHAR(10)                                                          /* 150 作成親PG       */
 , USRSET     VARCHAR(10)                                                          /* 160 作成社員       */
 , DYUPD      VARCHAR(14)                                                          /* 170 更新日時       */
 , PGUPD      VARCHAR(10)                                                          /* 180 更新PG         */
 , PGPUPD     VARCHAR(10)                                                          /* 190 更新親PG       */
 , USRUPD     VARCHAR(10)                                                          /* 200 更新者         */
);
